==> ui-18.5.2.tgz: package/components/radio/RadioGroup.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React, { useEffect, useState } from 'react';
import { getClassName } from '@react-devui/utils';
import { useGeneralContext } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DCompose } from '../compose';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DRadioGroupRenderer } from './RadioGroupRenderer';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DRadio.Group' });
export function DRadioGroup(props) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dFormControl, dList, dModel, dName, dVerticalCenter = false, dDisabled = false, dType, dSize, dVertical = false, onModelChange } = _a, restProps = __rest(_a, ["dFormControl", "dList", "dModel", "dName", "dVerticalCenter", "dDisabled", "dType", "dSize", "dVertical", "onModelChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize } = useGeneralContext();
    //#endregion
    const [isChange, setIsChange] = useState(false);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(() => {
        if (isChange) {
            setIsChange(false);
        }
    });
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    return (_jsx(DRadioGroupRenderer, { dFormControl: dFormControl, dList: dList, dModel: dModel, dName: dName, dVerticalCenter: dVerticalCenter, dDisabled: dDisabled, dRender: (nodes) => (_jsx(DCompose, Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}radio-group`, {
                [`${dPrefix}radio-group--default`]: isUndefined(dType),
                [`${dPrefix}radio-group--vertical`]: dVertical,
                'is-change': isChange,
            }), role: "radiogroup", dSize: size, dVertical: dVertical }, { __noStyle: isUndefined(dType) }, { children: React.Children.map(nodes, (node) => React.cloneElement(node, {
                __type: dType,
            })) }))), onModelChange: onModelChange }));
}

==> ui-18.5.7.tgz: package/components/radio/RadioGroup.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React, { useEffect, useState } from 'react';
import { getClassName } from '@react-devui/utils';
import { useGeneralContext } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DCompose } from '../compose';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DRadioGroupRenderer } from './RadioGroupRenderer';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DRadio.Group' });
export function DRadioGroup(props) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dFormControl, dList, dModel, dName, dDisabled = false, dType, dSize, dVertical = false, onModelChange } = _a, restProps = __rest(_a, ["dFormControl", "dList", "dModel", "dName", "dDisabled", "dType", "dSize", "dVertical", "onModelChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize } = useGeneralContext();
    //#endregion
    const [isChange, setIsChange] = useState(false);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(() => {
        if (isChange) {
            setIsChange(false);
        }
    });
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    return (_jsx(DRadioGroupRenderer, { dFormControl: dFormControl, dList: dList, dModel: dModel, dName: dName, dDisabled: dDisabled, dRender: (nodes) => (_jsx(DCompose, Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}radio-group`, {
                [`${dPrefix}radio-group--default`]: isUndefined(dType),
                [`${dPrefix}radio-group--vertical`]: dVertical,
                'is-change': isChange,
            }), role: "radiogroup", dSize: size, dVertical: dVertical }, { __noStyle: isUndefined(dType) }, { children: React.Children.map(nodes, (node) => React.cloneElement(node, {
                __type: dType,
            })) }))), onModelChange: onModelChange }));
}
